@@ -69,14 +69,11 @@ before ['cmd_start','cmd_continue'] => sub {
     return unless $self->has_rt;
 
     my $ticketname='RT'.$self->rt;
-    my $ticket;
-    unless ($self->rt_client) {
-        $self->insert_tag('RT'.$self->rt);
-    }
-    else {
-        $ticket = $self->rt_ticket;
+    $self->insert_tag($ticketname);
 
-        $self->insert_tag($ticketname);
+    my $ticket;
+    if ($self->rt_client) {
+        $ticket = $self->rt_ticket;
         if (defined $ticket) {
             $self->description($ticket->subject);
         }
@@ -85,13 +82,7 @@ before ['cmd_start','cmd_continue'] => sub {
     if ($self->meta->does_role('App::TimeTracker::Command::Git')) {
         my $branch = $ticketname;
         if ( $ticket ) {
-            my $subject = $ticket->subject;
-            $subject = NFKD($subject);
-            $subject =~ s/\p{NonspacingMark}//g;
-            $subject=~s/\W/_/g;
-            $subject=~s/_+/_/g;
-            $subject=~s/^_//;
-            $subject=~s/_$//;
+            my $subject = $self->safe_ticket_subject($ticket->subject);
             $branch .= '_'.$subject;
         }
         $self->branch($branch) unless $self->branch;
@@ -166,10 +157,22 @@ sub App::TimeTracker::Data::Task::rt_id {
     }
 }
 
+sub safe_ticket_subject {
+    my ($self, $subject) = @_;
+
+    $subject = NFKD($subject);
+    $subject =~ s/\p{NonspacingMark}//g;
+    $subject=~s/\W/_/g;
+    $subject=~s/_+/_/g;
+    $subject=~s/^_//;
+    $subject=~s/_$//;
+    return $subject;
+}
+
 no Moose::Role;
 1;
 
-
+__END__
 
 =pod
 
@@ -179,7 +182,7 @@ App::TimeTracker::Command::RT - App::TimeTracker RT plugin
 
 =head1 VERSION
 
-version 2.017
+version 2.018
 
 =head1 DESCRIPTION
 
@@ -268,7 +271,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
